@@ -2,10 +2,12 @@ package Email::Send;
 use strict;
 
 use vars qw[$VERSION];
-$VERSION   = '2.191';
+$VERSION   = '2.193';
 
 use Email::Simple;
-use Module::Pluggable search_path => 'Email::Send';
+use Module::Pluggable
+  search_path => 'Email::Send',
+  except      => $Email::Send::__plugin_exclusion;
 use Return::Value;
 use Scalar::Util ();
 
@@ -13,6 +15,15 @@ use Scalar::Util ();
 
 Email::Send - Simply Sending Email
 
+=head1 WAIT!  ACHTUNG!
+
+Email::Send is going away... well, not really going away, but it's being
+officially marked "out of favor."  It has API design problems that make it hard
+to usefully extend and rather than try to deprecate features and slowly ease in
+a new interface, we've released Email::SendB<er> which fixes these problems and
+others.  As of today, 2008-12-19, Email::Sender is young, but it's fairly
+well-tested.  Please consider using it instead for any new work.
+
 =head1 SYNOPSIS
 
   use Email::Send;
