@@ -1,12 +1,11 @@
 package Email::Send::NNTP;
-# $Id: NNTP.pm,v 1.6 2006/04/20 15:39:06 cwest Exp $
 use strict;
 
 use vars qw[$NNTP $VERSION];
 use Net::NNTP;
 use Return::Value;
 
-$VERSION   = '2.04';
+$VERSION   = '2.193';
 
 sub is_available {
     return   eval { require Net::NNTP }
@@ -64,7 +63,9 @@ L<perl>.
 
 =head1 AUTHOR
 
-Casey West, <F<casey@geeknest.com>>.
+Current maintainer: Ricardo SIGNES, <F<rjbs@cpan.org>>.
+
+Original author: Casey West, <F<casey@geeknest.com>>.
 
 =head1 COPYRIGHT
 
